geochemistrypi.data\_mining.model.func.algo\_regression package
===============================================================

Module contents
---------------

.. automodule:: geochemistrypi.data_mining.model.func.algo_regression
   :members:
   :undoc-members:
   :show-inheritance:
